/****************************************************************************
** Meta object code from reading C++ file 'ifirewallclientbackend.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-firewall-6.6.4/kcm/core/ifirewallclientbackend.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ifirewallclientbackend.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22IFirewallClientBackendE_t {};
} // unnamed namespace

template <> constexpr inline auto IFirewallClientBackend::qt_create_metaobjectdata<qt_meta_tag_ZN22IFirewallClientBackendE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "IFirewallClientBackend",
        "enabledChanged",
        "",
        "enabled",
        "defaultIncomingPolicyChanged",
        "defaultIncomingPolicy",
        "defaultOutgoingPolicyChanged",
        "defaultOutgoingPolicy",
        "logsAutoRefreshChanged",
        "logsAutoRefresh",
        "hasExecutableChanged",
        "changed",
        "showErrorMessage",
        "message",
        "addRule",
        "KJob*",
        "Rule*",
        "rule",
        "removeRule",
        "index",
        "updateRule",
        "moveRule",
        "from",
        "to",
        "setEnabled",
        "queryStatus",
        "FirewallClient::DefaultDataBehavior",
        "defaultsBehavior",
        "FirewallClient::ProfilesBehavior",
        "profilesBehavior",
        "setDefaultIncomingPolicy",
        "setDefaultOutgoingPolicy",
        "save",
        "supportsRuleUpdate"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'defaultIncomingPolicyChanged'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'defaultOutgoingPolicyChanged'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'logsAutoRefreshChanged'
        QtMocHelpers::SignalData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Signal 'hasExecutableChanged'
        QtMocHelpers::SignalData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'showErrorMessage'
        QtMocHelpers::SignalData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Method 'addRule'
        QtMocHelpers::MethodData<KJob *(Rule *)>(14, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Method 'removeRule'
        QtMocHelpers::MethodData<KJob *(int)>(18, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { QMetaType::Int, 19 },
        }}),
        // Method 'updateRule'
        QtMocHelpers::MethodData<KJob *(Rule *)>(20, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Method 'moveRule'
        QtMocHelpers::MethodData<KJob *(int, int)>(21, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { QMetaType::Int, 22 }, { QMetaType::Int, 23 },
        }}),
        // Method 'setEnabled'
        QtMocHelpers::MethodData<KJob *(bool)>(24, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { QMetaType::Bool, 3 },
        }}),
        // Method 'queryStatus'
        QtMocHelpers::MethodData<KJob *(FirewallClient::DefaultDataBehavior, FirewallClient::ProfilesBehavior)>(25, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { 0x80000000 | 26, 27 }, { 0x80000000 | 28, 29 },
        }}),
        // Method 'setDefaultIncomingPolicy'
        QtMocHelpers::MethodData<KJob *(QString)>(30, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { QMetaType::QString, 5 },
        }}),
        // Method 'setDefaultOutgoingPolicy'
        QtMocHelpers::MethodData<KJob *(QString)>(31, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { QMetaType::QString, 7 },
        }}),
        // Method 'save'
        QtMocHelpers::MethodData<KJob *()>(32, 2, QMC::AccessPublic, 0x80000000 | 15),
        // Method 'supportsRuleUpdate'
        QtMocHelpers::MethodData<bool() const>(33, 2, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<IFirewallClientBackend, qt_meta_tag_ZN22IFirewallClientBackendE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject IFirewallClientBackend::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22IFirewallClientBackendE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22IFirewallClientBackendE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22IFirewallClientBackendE_t>.metaTypes,
    nullptr
} };

void IFirewallClientBackend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<IFirewallClientBackend *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->enabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->defaultIncomingPolicyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->defaultOutgoingPolicyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->logsAutoRefreshChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->hasExecutableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->showErrorMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: { KJob* _r = _t->addRule((*reinterpret_cast<std::add_pointer_t<Rule*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<KJob**>(_a[0]) = std::move(_r); }  break;
        case 7: { KJob* _r = _t->removeRule((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<KJob**>(_a[0]) = std::move(_r); }  break;
        case 8: { KJob* _r = _t->updateRule((*reinterpret_cast<std::add_pointer_t<Rule*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<KJob**>(_a[0]) = std::move(_r); }  break;
        case 9: { KJob* _r = _t->moveRule((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<KJob**>(_a[0]) = std::move(_r); }  break;
        case 10: { KJob* _r = _t->setEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<KJob**>(_a[0]) = std::move(_r); }  break;
        case 11: { KJob* _r = _t->queryStatus((*reinterpret_cast<std::add_pointer_t<FirewallClient::DefaultDataBehavior>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<FirewallClient::ProfilesBehavior>>(_a[2])));
            if (_a[0]) *reinterpret_cast<KJob**>(_a[0]) = std::move(_r); }  break;
        case 12: { KJob* _r = _t->setDefaultIncomingPolicy((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<KJob**>(_a[0]) = std::move(_r); }  break;
        case 13: { KJob* _r = _t->setDefaultOutgoingPolicy((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<KJob**>(_a[0]) = std::move(_r); }  break;
        case 14: { KJob* _r = _t->save();
            if (_a[0]) *reinterpret_cast<KJob**>(_a[0]) = std::move(_r); }  break;
        case 15: { bool _r = _t->supportsRuleUpdate();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (IFirewallClientBackend::*)(bool )>(_a, &IFirewallClientBackend::enabledChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (IFirewallClientBackend::*)(const QString & )>(_a, &IFirewallClientBackend::defaultIncomingPolicyChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (IFirewallClientBackend::*)(const QString & )>(_a, &IFirewallClientBackend::defaultOutgoingPolicyChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (IFirewallClientBackend::*)(bool )>(_a, &IFirewallClientBackend::logsAutoRefreshChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (IFirewallClientBackend::*)(bool )>(_a, &IFirewallClientBackend::hasExecutableChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (IFirewallClientBackend::*)(const QString & )>(_a, &IFirewallClientBackend::showErrorMessage, 5))
            return;
    }
}

const QMetaObject *IFirewallClientBackend::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *IFirewallClientBackend::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22IFirewallClientBackendE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int IFirewallClientBackend::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void IFirewallClientBackend::enabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void IFirewallClientBackend::defaultIncomingPolicyChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void IFirewallClientBackend::defaultOutgoingPolicyChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void IFirewallClientBackend::logsAutoRefreshChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void IFirewallClientBackend::hasExecutableChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void IFirewallClientBackend::showErrorMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
