/****************************************************************************
** Meta object code from reading C++ file 'firewallclient.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-firewall-6.6.4/kcm/core/firewallclient.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'firewallclient.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14FirewallClientE_t {};
} // unnamed namespace

template <> constexpr inline auto FirewallClient::qt_create_metaobjectdata<qt_meta_tag_ZN14FirewallClientE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FirewallClient",
        "enabledChanged",
        "",
        "enabled",
        "defaultIncomingPolicyChanged",
        "defaultIncomingPolicy",
        "defaultOutgoingPolicyChanged",
        "defaultOutgoingPolicy",
        "logsAutoRefreshChanged",
        "logsAutoRefresh",
        "backendChanged",
        "backend",
        "hasExecutableChanged",
        "changed",
        "capabilitiesChanged",
        "FirewallClient::Capabilities",
        "capabilities",
        "showErrorMessage",
        "message",
        "knownProtocols",
        "knownInterfaces",
        "knownApplications",
        "isTcpAndUdp",
        "protocolIdx",
        "refresh",
        "ruleAt",
        "Rule*",
        "index",
        "addRule",
        "KJob*",
        "rule",
        "removeRule",
        "updateRule",
        "moveRule",
        "from",
        "to",
        "setEnabled",
        "setDefaultIncomingPolicy",
        "setDefaultOutgoingPolicy",
        "save",
        "createRuleFromConnection",
        "protocol",
        "localAddress",
        "foreignAddres",
        "status",
        "createRuleFromLog",
        "sourceAddress",
        "sourcePort",
        "destinationAddress",
        "destinationPort",
        "inn",
        "version",
        "rulesModel",
        "RuleListModel*",
        "logsModel",
        "LogListModel*",
        "hasExecutable",
        "Capabilities",
        "name",
        "supportsRuleUpdate",
        "Capability",
        "None",
        "SaveCapability"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void(const bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'defaultIncomingPolicyChanged'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'defaultOutgoingPolicyChanged'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'logsAutoRefreshChanged'
        QtMocHelpers::SignalData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Signal 'backendChanged'
        QtMocHelpers::SignalData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Signal 'hasExecutableChanged'
        QtMocHelpers::SignalData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Signal 'capabilitiesChanged'
        QtMocHelpers::SignalData<void(const FirewallClient::Capabilities &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'showErrorMessage'
        QtMocHelpers::SignalData<void(const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 },
        }}),
        // Method 'knownProtocols'
        QtMocHelpers::MethodData<QStringList()>(19, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Method 'knownInterfaces'
        QtMocHelpers::MethodData<QStringList()>(20, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Method 'knownApplications'
        QtMocHelpers::MethodData<QStringList()>(21, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Method 'isTcpAndUdp'
        QtMocHelpers::MethodData<bool(int)>(22, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 23 },
        }}),
        // Method 'refresh'
        QtMocHelpers::MethodData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'ruleAt'
        QtMocHelpers::MethodData<Rule *(int)>(25, 2, QMC::AccessPublic, 0x80000000 | 26, {{
            { QMetaType::Int, 27 },
        }}),
        // Method 'addRule'
        QtMocHelpers::MethodData<KJob *(Rule *)>(28, 2, QMC::AccessPublic, 0x80000000 | 29, {{
            { 0x80000000 | 26, 30 },
        }}),
        // Method 'removeRule'
        QtMocHelpers::MethodData<KJob *(int)>(31, 2, QMC::AccessPublic, 0x80000000 | 29, {{
            { QMetaType::Int, 27 },
        }}),
        // Method 'updateRule'
        QtMocHelpers::MethodData<KJob *(Rule *)>(32, 2, QMC::AccessPublic, 0x80000000 | 29, {{
            { 0x80000000 | 26, 30 },
        }}),
        // Method 'moveRule'
        QtMocHelpers::MethodData<KJob *(int, int)>(33, 2, QMC::AccessPublic, 0x80000000 | 29, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 35 },
        }}),
        // Method 'setEnabled'
        QtMocHelpers::MethodData<KJob *(bool)>(36, 2, QMC::AccessPublic, 0x80000000 | 29, {{
            { QMetaType::Bool, 3 },
        }}),
        // Method 'setDefaultIncomingPolicy'
        QtMocHelpers::MethodData<KJob *(const QString &)>(37, 2, QMC::AccessPublic, 0x80000000 | 29, {{
            { QMetaType::QString, 5 },
        }}),
        // Method 'setDefaultOutgoingPolicy'
        QtMocHelpers::MethodData<KJob *(const QString &)>(38, 2, QMC::AccessPublic, 0x80000000 | 29, {{
            { QMetaType::QString, 7 },
        }}),
        // Method 'save'
        QtMocHelpers::MethodData<KJob *()>(39, 2, QMC::AccessPublic, 0x80000000 | 29),
        // Method 'createRuleFromConnection'
        QtMocHelpers::MethodData<Rule *(const QString &, const QString &, const QString &, const QString &)>(40, 2, QMC::AccessPublic, 0x80000000 | 26, {{
            { QMetaType::QString, 41 }, { QMetaType::QString, 42 }, { QMetaType::QString, 43 }, { QMetaType::QString, 44 },
        }}),
        // Method 'createRuleFromLog'
        QtMocHelpers::MethodData<Rule *(const QString &, const QString &, const QString &, const QString &, const QString &, const QString &)>(45, 2, QMC::AccessPublic, 0x80000000 | 26, {{
            { QMetaType::QString, 41 }, { QMetaType::QString, 46 }, { QMetaType::QString, 47 }, { QMetaType::QString, 48 },
            { QMetaType::QString, 49 }, { QMetaType::QString, 50 },
        }}),
        // Method 'version'
        QtMocHelpers::MethodData<QString() const>(51, 2, QMC::AccessPublic, QMetaType::QString),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(3, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'defaultIncomingPolicy'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'defaultOutgoingPolicy'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags, 2),
        // property 'rulesModel'
        QtMocHelpers::PropertyData<RuleListModel*>(52, 0x80000000 | 53, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'logsModel'
        QtMocHelpers::PropertyData<LogListModel*>(54, 0x80000000 | 55, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'logsAutoRefresh'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'hasExecutable'
        QtMocHelpers::PropertyData<bool>(56, QMetaType::Bool, QMC::DefaultPropertyFlags, 5),
        // property 'capabilities'
        QtMocHelpers::PropertyData<Capabilities>(16, 0x80000000 | 57, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 6),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(58, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'supportsRuleUpdate'
        QtMocHelpers::PropertyData<bool>(59, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Capability'
        QtMocHelpers::EnumData<enum Capability>(60, 60, QMC::EnumFlags{}).add({
            {   61, Capability::None },
            {   62, Capability::SaveCapability },
        }),
        // flag 'Capabilities'
        QtMocHelpers::EnumData<Capabilities>(57, 60, QMC::EnumIsFlag).add({
            {   61, Capability::None },
            {   62, Capability::SaveCapability },
        }),
    };
    return QtMocHelpers::metaObjectData<FirewallClient, qt_meta_tag_ZN14FirewallClientE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject FirewallClient::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14FirewallClientE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14FirewallClientE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14FirewallClientE_t>.metaTypes,
    nullptr
} };

void FirewallClient::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FirewallClient *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->enabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->defaultIncomingPolicyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->defaultOutgoingPolicyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->logsAutoRefreshChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->backendChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->hasExecutableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->capabilitiesChanged((*reinterpret_cast<std::add_pointer_t<FirewallClient::Capabilities>>(_a[1]))); break;
        case 7: _t->showErrorMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: { QStringList _r = _t->knownProtocols();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 9: { QStringList _r = _t->knownInterfaces();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 10: { QStringList _r = _t->knownApplications();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 11: { bool _r = _t->isTcpAndUdp((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->refresh(); break;
        case 13: { Rule* _r = _t->ruleAt((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Rule**>(_a[0]) = std::move(_r); }  break;
        case 14: { KJob* _r = _t->addRule((*reinterpret_cast<std::add_pointer_t<Rule*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<KJob**>(_a[0]) = std::move(_r); }  break;
        case 15: { KJob* _r = _t->removeRule((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<KJob**>(_a[0]) = std::move(_r); }  break;
        case 16: { KJob* _r = _t->updateRule((*reinterpret_cast<std::add_pointer_t<Rule*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<KJob**>(_a[0]) = std::move(_r); }  break;
        case 17: { KJob* _r = _t->moveRule((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<KJob**>(_a[0]) = std::move(_r); }  break;
        case 18: { KJob* _r = _t->setEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<KJob**>(_a[0]) = std::move(_r); }  break;
        case 19: { KJob* _r = _t->setDefaultIncomingPolicy((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<KJob**>(_a[0]) = std::move(_r); }  break;
        case 20: { KJob* _r = _t->setDefaultOutgoingPolicy((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<KJob**>(_a[0]) = std::move(_r); }  break;
        case 21: { KJob* _r = _t->save();
            if (_a[0]) *reinterpret_cast<KJob**>(_a[0]) = std::move(_r); }  break;
        case 22: { Rule* _r = _t->createRuleFromConnection((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<Rule**>(_a[0]) = std::move(_r); }  break;
        case 23: { Rule* _r = _t->createRuleFromLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])));
            if (_a[0]) *reinterpret_cast<Rule**>(_a[0]) = std::move(_r); }  break;
        case 24: { QString _r = _t->version();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FirewallClient::*)(const bool )>(_a, &FirewallClient::enabledChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FirewallClient::*)(const QString & )>(_a, &FirewallClient::defaultIncomingPolicyChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FirewallClient::*)(const QString & )>(_a, &FirewallClient::defaultOutgoingPolicyChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FirewallClient::*)(bool )>(_a, &FirewallClient::logsAutoRefreshChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FirewallClient::*)(const QString & )>(_a, &FirewallClient::backendChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (FirewallClient::*)(bool )>(_a, &FirewallClient::hasExecutableChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (FirewallClient::*)(const FirewallClient::Capabilities & )>(_a, &FirewallClient::capabilitiesChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (FirewallClient::*)(const QString & )>(_a, &FirewallClient::showErrorMessage, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->defaultIncomingPolicy(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->defaultOutgoingPolicy(); break;
        case 3: *reinterpret_cast<RuleListModel**>(_v) = _t->rulesModel(); break;
        case 4: *reinterpret_cast<LogListModel**>(_v) = _t->logsModel(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->logsAutoRefresh(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->hasExecutable(); break;
        case 7: QtMocHelpers::assignFlags<Capabilities>(_v, _t->capabilities()); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->supportsRuleUpdate(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 5: _t->setLogsAutoRefresh(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *FirewallClient::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FirewallClient::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14FirewallClientE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int FirewallClient::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 25;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void FirewallClient::enabledChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void FirewallClient::defaultIncomingPolicyChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void FirewallClient::defaultOutgoingPolicyChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void FirewallClient::logsAutoRefreshChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void FirewallClient::backendChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void FirewallClient::hasExecutableChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void FirewallClient::capabilitiesChanged(const FirewallClient::Capabilities & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void FirewallClient::showErrorMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
