/****************************************************************************
** Meta object code from reading C++ file 'types.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-firewall-6.6.4/kcm/core/types.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'types.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5TypesE_t {};
} // unnamed namespace

template <> constexpr inline auto Types::qt_create_metaobjectdata<qt_meta_tag_ZN5TypesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Types",
        "LogLevel",
        "LOG_OFF",
        "LOG_LOW",
        "LOG_MEDIUM",
        "LOG_HIGH",
        "LOG_FULL",
        "LOG_COUNT",
        "Logging",
        "LOGGING_OFF",
        "LOGGING_NEW",
        "LOGGING_ALL",
        "LOGGING_COUNT",
        "Policy",
        "POLICY_ALLOW",
        "POLICY_DENY",
        "POLICY_REJECT",
        "POLICY_LIMIT",
        "POLICY_COUNT",
        "POLICY_COUNT_DEFAULT",
        "PredefinedPort",
        "PP_AMULE",
        "PP_DELUGE",
        "PP_KTORRENT",
        "PP_NICOTINE",
        "PP_QBITTORRNET",
        "PP_TRANSMISSION",
        "PP_IM_ICQ",
        "PP_IM_JABBER",
        "PP_IM_WLM",
        "PP_IM_YAHOO",
        "PP_FTP",
        "PP_HTTP",
        "PP_HTTPS",
        "PP_IMAP",
        "PP_IMAPS",
        "PP_POP3",
        "PP_POP3S",
        "PP_SMTP",
        "PP_NFS",
        "PP_SAMBA",
        "PP_SSH",
        "PP_VNC",
        "PP_ZEROCONF",
        "PP_TELNET",
        "PP_NTP",
        "PP_CUPS",
        "PP_COUNT"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'LogLevel'
        QtMocHelpers::EnumData<LogLevel>(1, 1, QMC::EnumFlags{}).add({
            {    2, LogLevel::LOG_OFF },
            {    3, LogLevel::LOG_LOW },
            {    4, LogLevel::LOG_MEDIUM },
            {    5, LogLevel::LOG_HIGH },
            {    6, LogLevel::LOG_FULL },
            {    7, LogLevel::LOG_COUNT },
        }),
        // enum 'Logging'
        QtMocHelpers::EnumData<Logging>(8, 8, QMC::EnumFlags{}).add({
            {    9, Logging::LOGGING_OFF },
            {   10, Logging::LOGGING_NEW },
            {   11, Logging::LOGGING_ALL },
            {   12, Logging::LOGGING_COUNT },
        }),
        // enum 'Policy'
        QtMocHelpers::EnumData<Policy>(13, 13, QMC::EnumFlags{}).add({
            {   14, Policy::POLICY_ALLOW },
            {   15, Policy::POLICY_DENY },
            {   16, Policy::POLICY_REJECT },
            {   17, Policy::POLICY_LIMIT },
            {   18, Policy::POLICY_COUNT },
            {   19, Policy::POLICY_COUNT_DEFAULT },
        }),
        // enum 'PredefinedPort'
        QtMocHelpers::EnumData<PredefinedPort>(20, 20, QMC::EnumFlags{}).add({
            {   21, PredefinedPort::PP_AMULE },
            {   22, PredefinedPort::PP_DELUGE },
            {   23, PredefinedPort::PP_KTORRENT },
            {   24, PredefinedPort::PP_NICOTINE },
            {   25, PredefinedPort::PP_QBITTORRNET },
            {   26, PredefinedPort::PP_TRANSMISSION },
            {   27, PredefinedPort::PP_IM_ICQ },
            {   28, PredefinedPort::PP_IM_JABBER },
            {   29, PredefinedPort::PP_IM_WLM },
            {   30, PredefinedPort::PP_IM_YAHOO },
            {   31, PredefinedPort::PP_FTP },
            {   32, PredefinedPort::PP_HTTP },
            {   33, PredefinedPort::PP_HTTPS },
            {   34, PredefinedPort::PP_IMAP },
            {   35, PredefinedPort::PP_IMAPS },
            {   36, PredefinedPort::PP_POP3 },
            {   37, PredefinedPort::PP_POP3S },
            {   38, PredefinedPort::PP_SMTP },
            {   39, PredefinedPort::PP_NFS },
            {   40, PredefinedPort::PP_SAMBA },
            {   41, PredefinedPort::PP_SSH },
            {   42, PredefinedPort::PP_VNC },
            {   43, PredefinedPort::PP_ZEROCONF },
            {   44, PredefinedPort::PP_TELNET },
            {   45, PredefinedPort::PP_NTP },
            {   46, PredefinedPort::PP_CUPS },
            {   47, PredefinedPort::PP_COUNT },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN5TypesE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN5TypesE =
    Types::qt_create_metaobjectdata<qt_meta_tag_ZN5TypesE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN5TypesE =
    qt_staticMetaObjectContent_ZN5TypesE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN5TypesE =
    qt_staticMetaObjectContent_ZN5TypesE.relocatingData;

Q_CONSTINIT const QMetaObject Types::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN5TypesE.stringdata,
    qt_staticMetaObjectStaticContent_ZN5TypesE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN5TypesE.metaTypes,
    nullptr
} };

QT_WARNING_POP
